__author__ = 'Managed by Q, Inc.',
__author_email__ = 'open-source@managedbyq.com'
__description__ = 'MBQ Ranch'
__license__ = 'Apache 2.0'
__title__ = 'mbq.ranch'
__url__ = 'https://github.com/managedbyq/mbq.ranch'
__version__ = '0.0.1'
