# -*- coding: utf-8 -*-
# Generated by Django 1.11.15 on 2018-10-01 17:56
from django.db import migrations, models

class Migration(migrations.Migration):

    dependencies = [
        ('ranch', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='loggedtask',
            name='queue',
            field=models.CharField(max_length=128, null=True),
        ),
    ]
